@@ -758,14 +758,17 @@ void AgendaViewPrivate::calendarIncidenceAdded(const KCalendarCore::Incidence::P
     }
 
     if (incidence->hasRecurrenceId()) {
-        if (auto mainIncidence = q->calendar2(incidence)->incidence(incidence->uid())) {
-            // Reevaluate the main event instead, if it was inserted before this one.
-            reevaluateIncidence(mainIncidence);
-        } else if (q->displayIncidence(incidence, false)) {
-            // Display disassociated occurrences because errors sometimes destroy
-            // the main recurring incidence.
-            mAgenda->checkScrollBoundaries();
-            q->scheduleUpdateEventIndicators();
+        const auto cal = q->calendar2(incidence);
+        if (cal) {
+            if (auto mainIncidence = cal->incidence(incidence->uid())) {
+                // Reevaluate the main event instead, if it was inserted before this one.
+                reevaluateIncidence(mainIncidence);
+            } else if (q->displayIncidence(incidence, false)) {
+                // Display disassociated occurrences because errors sometimes destroy
+                // the main recurring incidence.
+                mAgenda->checkScrollBoundaries();
+                q->scheduleUpdateEventIndicators();
+            }
         }
     } else if (incidence->recurs()) {
         // Reevaluate recurring incidences to clean up any disassociated
@@ -808,8 +811,11 @@ void AgendaViewPrivate::calendarIncidenceChanged(const KCalendarCore::Incidence:
 
     if (incidence->hasRecurrenceId() && mViewCalendar->isValid(incidence)) {
         // Reevaluate the main event instead, if it exists
-        KCalendarCore::Incidence::Ptr mainIncidence = q->calendar2(incidence)->incidence(incidence->uid());
-        reevaluateIncidence(mainIncidence ? mainIncidence : incidence);
+        const auto cal = q->calendar2(incidence);
+        if (cal) {
+            KCalendarCore::Incidence::Ptr mainIncidence = cal->incidence(incidence->uid());
+            reevaluateIncidence(mainIncidence ? mainIncidence : incidence);
+        }
     } else {
         reevaluateIncidence(incidence);
     }
@@ -833,9 +839,12 @@ void AgendaViewPrivate::calendarIncidenceDeleted(const KCalendarCore::Incidence:
         // Reevaluate the main event, if it exists. The exception was removed so the main recurrent series
         // will no be bigger.
         if (mViewCalendar->isValid(incidence->uid())) {
-            KCalendarCore::Incidence::Ptr mainIncidence = q->calendar2(incidence->uid())->incidence(incidence->uid());
-            if (mainIncidence) {
-                reevaluateIncidence(mainIncidence);
+            const auto cal = q->calendar2(incidence->uid());
+            if (cal) {
+                KCalendarCore::Incidence::Ptr mainIncidence = cal->incidence(incidence->uid());
+                if (mainIncidence) {
+                    reevaluateIncidence(mainIncidence);
+                }
             }
         }
     } else if (mightBeVisible(incidence)) {
@@ -1224,12 +1233,20 @@ bool AgendaView::eventFilter(QObject *object, QEvent *event)
 
 KCalendarCore::Calendar::Ptr AgendaView::calendar2(const KCalendarCore::Incidence::Ptr &incidence) const
 {
-    return d->mViewCalendar->findCalendar(incidence)->getCalendar();
+    const auto cal = d->mViewCalendar->findCalendar(incidence);
+    if (cal) {
+        return cal->getCalendar();
+    }
+    return {};
 }
 
 KCalendarCore::Calendar::Ptr AgendaView::calendar2(const QString &incidenceIdentifier) const
 {
-    return d->mViewCalendar->findCalendar(incidenceIdentifier)->getCalendar();
+    const auto cal = d->mViewCalendar->findCalendar(incidenceIdentifier);
+    if (cal) {
+        return cal->getCalendar();
+    }
+    return {};
 }
 
 void AgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &cal)
@@ -1664,6 +1681,24 @@ void AgendaView::updateTimeBarWidth()
     d->mBottomDayLabelsFrame->setWeekWidth(timeBarWidth);
 }
 
+// By deafult QDateTime::toTimeSpec() will turn Qt::TimeZone to Qt::LocalTime,
+// which would turn the event's timezone into "floating". This code actually
+// preserves the timezone, if the spec is Qt::TimeZone.
+static QDateTime copyTimeSpec(QDateTime dt, const QDateTime &source)
+{
+    switch (source.timeSpec()) {
+    case Qt::TimeZone:
+        return dt.toTimeZone(source.timeZone());
+    case Qt::LocalTime:
+    case Qt::UTC:
+        return dt.toTimeSpec(source.timeSpec());
+    case Qt::OffsetFromUTC:
+        return dt.toOffsetFromUtc(source.offsetFromUtc());
+    }
+
+    Q_UNREACHABLE();
+}
+
 void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::Collection::Id collectionId)
 {
     qCDebug(CALENDARVIEW_LOG) << item->text() << "; item->cellXLeft(): " << item->cellXLeft() << "; item->cellYTop(): " << item->cellYTop()
@@ -1757,8 +1792,8 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
          *
          * TODO: We need a better hashing mechanism for CalendarLocal.
          */
-        ev->setDtEnd(endDt.toTimeSpec(incidence->dateTime(KCalendarCore::Incidence::RoleEnd).timeSpec()));
-        incidence->setDtStart(startDt.toTimeSpec(incidence->dtStart().timeSpec()));
+        ev->setDtEnd(copyTimeSpec(endDt, incidence->dateTime(KCalendarCore::Incidence::RoleEnd)));
+        incidence->setDtStart(copyTimeSpec(startDt, incidence->dtStart()));
     } else if (const KCalendarCore::Todo::Ptr td = CalendarSupport::todo(incidence)) {
         endDt = td->dtDue(true).toLocalTime().addDays(daysOffset);
         endDt.setTime(td->allDay() ? QTime(00, 00, 00) : endTime);
@@ -1772,12 +1807,12 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
         const auto shift = td->dtDue(true).secsTo(endDt);
         startDt = td->dtStart(true).addSecs(shift);
         if (td->hasStartDate()) {
-            td->setDtStart(startDt.toTimeSpec(incidence->dtStart().timeSpec()));
+            td->setDtStart(copyTimeSpec(startDt, incidence->dtStart()));
         }
         if (td->recurs()) {
             td->setDtRecurrence(td->dtRecurrence().addSecs(shift));
         }
-        td->setDtDue(endDt.toTimeSpec(td->dtDue().timeSpec()), true);
+        td->setDtDue(copyTimeSpec(endDt, td->dtDue()), true);
     }
 
     if (!incidence->hasRecurrenceId()) {
@@ -1978,7 +2013,8 @@ bool AgendaView::displayIncidence(const KCalendarCore::Incidence::Ptr &incidence
     if (incidence->hasRecurrenceId()) {
         // Normally a disassociated instance belongs to a recurring instance that
         // displays it.
-        if (calendar2(incidence)->incidence(incidence->uid())) {
+        const auto cal = calendar2(incidence);
+        if (cal && cal->incidence(incidence->uid())) {
             return false;
         }
     }
@@ -2387,12 +2423,15 @@ void AgendaView::removeIncidence(const KCalendarCore::Incidence::Ptr &incidence)
     if (!incidence->hasRecurrenceId() && d->mViewCalendar->isValid(incidence->uid())) {
         // Deleted incidence is an main incidence
         // Delete all exceptions as well
-        const KCalendarCore::Incidence::List exceptions = calendar2(incidence->uid())->instances(incidence);
-        for (const KCalendarCore::Incidence::Ptr &exception : exceptions) {
-            if (exception->allDay()) {
-                d->mAllDayAgenda->removeIncidence(exception);
-            } else {
-                d->mAgenda->removeIncidence(exception);
+        const auto cal = calendar2(incidence->uid());
+        if (cal) {
+            const KCalendarCore::Incidence::List exceptions = cal->instances(incidence);
+            for (const KCalendarCore::Incidence::Ptr &exception : exceptions) {
+                if (exception->allDay()) {
+                    d->mAllDayAgenda->removeIncidence(exception);
+                } else {
+                    d->mAgenda->removeIncidence(exception);
+                }
             }
         }
     }
