@@ -1,34 +1,18 @@
 /*
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "helper.h"
-#include "prefs.h"
 #include "calendarview_debug.h"
+#include "prefs.h"
 
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
-#include <AkonadiCore/CollectionColorAttribute>
-#include <AkonadiCore/CollectionModifyJob>
+#include <Akonadi/CollectionColorAttribute>
+#include <Akonadi/CollectionModifyJob>
 
 #include <QIcon>
 #include <QPixmap>
@@ -46,7 +30,7 @@ QColor EventViews::getTextColor(const QColor &c)
 
 void EventViews::setResourceColor(const Akonadi::Collection &coll, const QColor &color, const PrefsPtr &preferences)
 {
-    if (!coll.isValid()) {
+    if (!coll.isValid() || !color.isValid()) {
         return;
     }
 
@@ -54,15 +38,16 @@ void EventViews::setResourceColor(const Akonadi::Collection &coll, const QColor
 
     // Save the color in akonadi (so the resource can even save it server-side)
     Akonadi::Collection collection = coll;
-    Akonadi::CollectionColorAttribute *colorAttr
-            = collection.attribute<Akonadi::CollectionColorAttribute>(Akonadi::Collection::AddIfMissing);
-    colorAttr->setColor(color);
-    Akonadi::CollectionModifyJob *job = new Akonadi::CollectionModifyJob(collection, nullptr);
-    QObject::connect(job, &Akonadi::CollectionModifyJob::result, [=]() {
-        if (job->error()) {
-            qCWarning(CALENDARVIEW_LOG) << "Failed to set CollectionColorAttribute:" << job->errorString();
-        }
-    });
+    auto colorAttr = collection.attribute<Akonadi::CollectionColorAttribute>(Akonadi::Collection::AddIfMissing);
+    if (colorAttr) {
+        colorAttr->setColor(color);
+        auto job = new Akonadi::CollectionModifyJob(collection, nullptr);
+        QObject::connect(job, &Akonadi::CollectionModifyJob::result, [=]() {
+            if (job->error()) {
+                qCWarning(CALENDARVIEW_LOG) << "Failed to set CollectionColorAttribute:" << job->errorString();
+            }
+        });
+    }
 
     // Also save the color in eventviewsrc (mostly historical)
     preferences->setResourceColor(id, color);
@@ -71,7 +56,7 @@ void EventViews::setResourceColor(const Akonadi::Collection &coll, const QColor
 QColor EventViews::resourceColor(const Akonadi::Collection &coll, const PrefsPtr &preferences)
 {
     if (!coll.isValid()) {
-        return QColor();
+        return {};
     }
     const QString id = QString::number(coll.id());
     // Color stored in eventviewsrc (and in memory)
@@ -81,8 +66,7 @@ QColor EventViews::resourceColor(const Akonadi::Collection &coll, const PrefsPtr
     }
     // Color stored in akonadi
     if (coll.hasAttribute<Akonadi::CollectionColorAttribute>()) {
-        const Akonadi::CollectionColorAttribute *colorAttr
-            = coll.attribute<Akonadi::CollectionColorAttribute>();
+        const auto colorAttr = coll.attribute<Akonadi::CollectionColorAttribute>();
         if (colorAttr && colorAttr->color().isValid()) {
             return colorAttr->color();
         }
@@ -94,12 +78,12 @@ QColor EventViews::resourceColor(const Akonadi::Collection &coll, const PrefsPtr
 QColor EventViews::resourceColor(const Akonadi::Item &item, const PrefsPtr &preferences)
 {
     if (!item.isValid()) {
-        return QColor();
+        return {};
     }
     return resourceColor(item.parentCollection(), preferences);
 }
 
-int EventViews::yearDiff(const QDate &start, const QDate &end)
+int EventViews::yearDiff(QDate start, QDate end)
 {
     return end.year() - start.year();
 }
