@@ -12,7 +12,9 @@
 #include "prefs.h"
 #include "prefs_base.h" // Ugly, but needed for the Enums
 
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/IncidenceChanger>
+#include <Akonadi/TagCache>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
@@ -22,6 +24,8 @@
 #include "calendarview_debug.h"
 #include <KMessageBox>
 
+#include <QDrag>
+
 using namespace EventViews;
 using namespace KCalendarCore;
 
@@ -156,6 +160,12 @@ void MonthItem::moveBy(int offsetToPreviousDate)
     updateMonthGraphicsItems();
 }
 
+void MonthItem::moveTo(QDate date)
+{
+    mOverrideStartDate = date;
+    updateMonthGraphicsItems();
+}
+
 void MonthItem::updateGeometry()
 {
     for (MonthGraphicsItem *item : std::as_const(mMonthGraphicsItemList)) {
@@ -172,7 +182,7 @@ void MonthItem::setZValue(qreal z)
 
 QDate MonthItem::startDate() const
 {
-    if (isMoving() || isResizing()) {
+    if ((isMoving() || isResizing()) && mOverrideStartDate.isValid()) {
         return mOverrideStartDate;
     }
 
@@ -181,7 +191,7 @@ QDate MonthItem::startDate() const
 
 QDate MonthItem::endDate() const
 {
-    if (isMoving() || isResizing()) {
+    if ((isMoving() || isResizing()) && mOverrideStartDate.isValid()) {
         return mOverrideStartDate.addDays(mOverrideDaySpan);
     }
 
@@ -308,9 +318,7 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
     }
 }
 
-IncidenceMonthItem::~IncidenceMonthItem()
-{
-}
+IncidenceMonthItem::~IncidenceMonthItem() = default;
 
 bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 {
@@ -380,8 +388,14 @@ void IncidenceMonthItem::finalizeMove(const QDate &newStartDate)
 {
     Q_ASSERT(isMoveable());
 
-    if (startDate().isValid() && newStartDate.isValid()) {
-        updateDates(startDate().daysTo(newStartDate), startDate().daysTo(newStartDate));
+    if (startDate().isValid()) {
+        if (newStartDate.isValid()) {
+            updateDates(startDate().daysTo(newStartDate), startDate().daysTo(newStartDate));
+        } else {
+            if (QDrag *drag = CalendarSupport::createDrag(akonadiItem(), this)) {
+                drag->exec();
+            }
+        }
     }
 }
 
@@ -426,7 +440,7 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
                 changer->createIncidence(newIncidence, item.parentCollection(), parentWidget());
                 changer->endAtomicOperation();
             } else {
-                KMessageBox::sorry(parentWidget(),
+                KMessageBox::error(parentWidget(),
                                    i18n("Unable to add the exception item to the calendar. "
                                         "No change will be done."),
                                    i18n("Error Occurred"));
@@ -485,7 +499,10 @@ QString IncidenceMonthItem::text(bool end) const
 
 QString IncidenceMonthItem::toolTipText(const QDate &date) const
 {
-    return KCalUtils::IncidenceFormatter::toolTipStr(CalendarSupport::displayName(mCalendar.data(), akonadiItem().parentCollection()), mIncidence, date, true);
+    return KCalUtils::IncidenceFormatter::toolTipStr(Akonadi::CalendarUtils::displayName(mCalendar.data(), akonadiItem().parentCollection()),
+                                                     mIncidence,
+                                                     date,
+                                                     true);
 }
 
 QVector<QPixmap> IncidenceMonthItem::icons() const
@@ -530,8 +547,7 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
 
         // ret << monthScene()->eventPixmap();
     } else if ((mIsTodo || mIsJournal) && icons.contains(mIsTodo ? EventView::TaskIcon : EventView::JournalIcon)) {
-        QDateTime occurrenceDateTime = mIncidence->dateTime(Incidence::RoleRecurrenceStart);
-        occurrenceDateTime.setDate(realStartDate());
+        QDateTime occurrenceDateTime = mIncidence->dateTime(Incidence::RoleRecurrenceStart).addDays(mRecurDayOffset);
 
         const QString incidenceIconName = mIncidence->iconName(occurrenceDateTime);
         if (customIconName != incidenceIconName) {
@@ -562,14 +578,14 @@ QColor IncidenceMonthItem::catColor() const
     const auto &prefs = monthScene()->monthView()->preferences();
 
     const auto &categories = mIncidence->categories();
-    if (categories.isEmpty() || !CalendarSupport::KCalPrefs::instance()->hasCategoryColor(categories.first())) {
+    if (categories.isEmpty() || !Akonadi::TagCache::instance()->tagColor(categories.first()).isValid()) {
         const auto &colorPreference = prefs->monthViewColors();
         if (colorPreference == PrefsBase::CategoryOnly) {
             return CalendarSupport::KCalPrefs::instance()->unsetCategoryColor();
         }
         return EventViews::resourceColor(akonadiItem(), prefs);
     }
-    return CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first());
+    return Akonadi::TagCache::instance()->tagColor(categories.first());
 }
 
 QColor IncidenceMonthItem::bgColor() const
@@ -577,7 +593,7 @@ QColor IncidenceMonthItem::bgColor() const
     const auto &prefs = monthScene()->monthView()->preferences();
 
     if (!prefs->todosUseCategoryColors() && mIsTodo) {
-        Todo::Ptr todo = CalendarSupport::todo(akonadiItem());
+        Todo::Ptr todo = Akonadi::CalendarUtils::todo(akonadiItem());
         Q_ASSERT(todo);
         if (todo) {
             // this is dtDue if there's no dtRecurrence
@@ -613,7 +629,7 @@ Akonadi::Item IncidenceMonthItem::akonadiItem() const
     if (mIncidence) {
         return monthScene()->mMonthView->calendar()->item(mIncidence);
     } else {
-        return Akonadi::Item();
+        return {};
     }
 }
 
@@ -679,9 +695,7 @@ HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, QDate startDate, QDat
 {
 }
 
-HolidayMonthItem::~HolidayMonthItem()
-{
-}
+HolidayMonthItem::~HolidayMonthItem() = default;
 
 bool HolidayMonthItem::greaterThanFallback(const MonthItem *other) const
 {
