@@ -14,11 +14,11 @@
 #include "configdialoginterface.h"
 #include "prefs.h"
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/ETMViewStateSaver>
 #include <Akonadi/EntityTreeModel>
 
 #include <CalendarSupport/CollectionSelection>
-#include <CalendarSupport/Utils>
 
 #include <KCheckableProxyModel>
 #include <KLocalizedString>
@@ -136,6 +136,7 @@ public:
     QLabel *mLabel = nullptr;
     QWidget *mRightDummyWidget = nullptr;
     QHash<QString, KViewStateMaintainer<ETMViewStateSaver> *> mSelectionSavers;
+    QMetaObject::Connection m_selectionChangeConn;
 };
 
 MultiAgendaView::MultiAgendaView(QWidget *parent)
@@ -230,9 +231,9 @@ void MultiAgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
         proxy->setSourceModel(calendar->entityTreeModel());
     }
 
-    disconnect(nullptr, SIGNAL(selectionChanged(Akonadi::Collection::List, Akonadi::Collection::List)), this, SLOT(forceRecreateViews()));
-
-    connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged, this, &MultiAgendaView::forceRecreateViews);
+    disconnect(d->m_selectionChangeConn);
+    d->m_selectionChangeConn =
+        connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged, this, &MultiAgendaView::forceRecreateViews);
 
     recreateViews();
 }
@@ -303,38 +304,41 @@ void MultiAgendaViewPrivate::deleteViews()
 
 void MultiAgendaViewPrivate::setupViews()
 {
-    for (AgendaView *agenda : std::as_const(mAgendaViews)) {
-        q->connect(agenda, SIGNAL(newEventSignal()), q, SIGNAL(newEventSignal()));
-        q->connect(agenda, SIGNAL(newEventSignal(QDate)), q, SIGNAL(newEventSignal(QDate)));
-        q->connect(agenda, SIGNAL(newEventSignal(QDateTime)), q, SIGNAL(newEventSignal(QDateTime)));
-        q->connect(agenda, SIGNAL(newEventSignal(QDateTime, QDateTime)), q, SIGNAL(newEventSignal(QDateTime, QDateTime)));
+    for (AgendaView *agendaView : std::as_const(mAgendaViews)) {
+        q->connect(agendaView, qOverload<>(&EventView::newEventSignal), q, qOverload<>(&EventView::newEventSignal));
+        q->connect(agendaView, qOverload<const QDate &>(&EventView::newEventSignal), q, qOverload<const QDate &>(&EventView::newEventSignal));
+        q->connect(agendaView, qOverload<const QDateTime &>(&EventView::newEventSignal), q, qOverload<const QDateTime &>(&EventView::newEventSignal));
+        q->connect(agendaView,
+                   qOverload<const QDateTime &, const QDateTime &>(&EventView::newEventSignal),
+                   q,
+                   qOverload<const QDateTime &>(&EventView::newEventSignal));
 
-        q->connect(agenda, &EventView::editIncidenceSignal, q, &EventView::editIncidenceSignal);
-        q->connect(agenda, &EventView::showIncidenceSignal, q, &EventView::showIncidenceSignal);
-        q->connect(agenda, &EventView::deleteIncidenceSignal, q, &EventView::deleteIncidenceSignal);
+        q->connect(agendaView, &EventView::editIncidenceSignal, q, &EventView::editIncidenceSignal);
+        q->connect(agendaView, &EventView::showIncidenceSignal, q, &EventView::showIncidenceSignal);
+        q->connect(agendaView, &EventView::deleteIncidenceSignal, q, &EventView::deleteIncidenceSignal);
 
-        q->connect(agenda, &EventView::incidenceSelected, q, &EventView::incidenceSelected);
+        q->connect(agendaView, &EventView::incidenceSelected, q, &EventView::incidenceSelected);
 
-        q->connect(agenda, &EventView::cutIncidenceSignal, q, &EventView::cutIncidenceSignal);
-        q->connect(agenda, &EventView::copyIncidenceSignal, q, &EventView::copyIncidenceSignal);
-        q->connect(agenda, &EventView::pasteIncidenceSignal, q, &EventView::pasteIncidenceSignal);
-        q->connect(agenda, &EventView::toggleAlarmSignal, q, &EventView::toggleAlarmSignal);
-        q->connect(agenda, &EventView::dissociateOccurrencesSignal, q, &EventView::dissociateOccurrencesSignal);
+        q->connect(agendaView, &EventView::cutIncidenceSignal, q, &EventView::cutIncidenceSignal);
+        q->connect(agendaView, &EventView::copyIncidenceSignal, q, &EventView::copyIncidenceSignal);
+        q->connect(agendaView, &EventView::pasteIncidenceSignal, q, &EventView::pasteIncidenceSignal);
+        q->connect(agendaView, &EventView::toggleAlarmSignal, q, &EventView::toggleAlarmSignal);
+        q->connect(agendaView, &EventView::dissociateOccurrencesSignal, q, &EventView::dissociateOccurrencesSignal);
 
-        q->connect(agenda, &EventView::newTodoSignal, q, &EventView::newTodoSignal);
+        q->connect(agendaView, &EventView::newTodoSignal, q, &EventView::newTodoSignal);
 
-        q->connect(agenda, &EventView::incidenceSelected, q, &MultiAgendaView::slotSelectionChanged);
+        q->connect(agendaView, &EventView::incidenceSelected, q, &MultiAgendaView::slotSelectionChanged);
 
-        q->connect(agenda, &AgendaView::timeSpanSelectionChanged, q, &MultiAgendaView::slotClearTimeSpanSelection);
+        q->connect(agendaView, &AgendaView::timeSpanSelectionChanged, q, &MultiAgendaView::slotClearTimeSpanSelection);
 
-        q->disconnect(agenda->agenda(), SIGNAL(zoomView(int, QPoint, Qt::Orientation)), agenda, nullptr);
-        q->connect(agenda->agenda(), &Agenda::zoomView, q, &MultiAgendaView::zoomView);
+        q->disconnect(agendaView->agenda(), &Agenda::zoomView, agendaView, nullptr);
+        q->connect(agendaView->agenda(), &Agenda::zoomView, q, &MultiAgendaView::zoomView);
     }
 
     AgendaView *lastView = mAgendaViews.last();
-    for (AgendaView *agenda : std::as_const(mAgendaViews)) {
-        if (agenda != lastView) {
-            q->connect(agenda->agenda()->verticalScrollBar(),
+    for (AgendaView *agendaView : std::as_const(mAgendaViews)) {
+        if (agendaView != lastView) {
+            q->connect(agendaView->agenda()->verticalScrollBar(),
                        &QAbstractSlider::valueChanged,
                        lastView->agenda()->verticalScrollBar(),
                        &QAbstractSlider::setValue);
@@ -474,7 +478,7 @@ AgendaView *MultiAgendaViewPrivate::createView(const QString &title)
 
 void MultiAgendaViewPrivate::addView(const Akonadi::Collection &collection)
 {
-    AgendaView *av = createView(CalendarSupport::displayName(q->calendar().data(), collection));
+    AgendaView *av = createView(Akonadi::CalendarUtils::displayName(q->calendar().data(), collection));
     av->setCollectionId(collection.id());
 }
 
