@@ -1,34 +1,16 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "tododelegates.h"
-#include "todomodel.h"
 #include "todoviewview.h"
 
-#include <AkonadiWidgets/TagSelectionComboBox>
-#include <Akonadi/Calendar/ETMCalendar>
-#include <CalendarSupport/CategoryConfig>
+#include <Akonadi/TagSelectionComboBox>
+#include <Akonadi/TodoModel>
 #include <CalendarSupport/CategoryHierarchyReader>
 
 #include <KCalendarCore/CalFilter>
@@ -58,7 +40,7 @@ void TodoCompleteDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
 
     if (index.data(Qt::EditRole).toInt() > 0) {
         bool isEditing = false;
-        TodoViewView *view = qobject_cast<TodoViewView *>(parent());
+        auto view = qobject_cast<TodoViewView *>(parent());
         if (view) {
             isEditing = view->isEditing(index);
         }
@@ -87,12 +69,10 @@ QSize TodoCompleteDelegate::sizeHint(const QStyleOptionViewItem &option, const Q
     pbOption.QStyleOption::operator=(option);
     initStyleOptionProgressBar(&pbOption, index);
 
-    return style->sizeFromContents(QStyle::CT_ProgressBar, &pbOption,
-                                   QSize(), opt.widget);
+    return style->sizeFromContents(QStyle::CT_ProgressBar, &pbOption, QSize(), opt.widget);
 }
 
-void TodoCompleteDelegate::initStyleOptionProgressBar(
-    QStyleOptionProgressBar *option, const QModelIndex &index) const
+void TodoCompleteDelegate::initStyleOptionProgressBar(QStyleOptionProgressBar *option, const QModelIndex &index) const
 {
     option->rect.adjust(0, 1, 0, -1);
     option->maximum = 100;
@@ -101,14 +81,15 @@ void TodoCompleteDelegate::initStyleOptionProgressBar(
     option->text = index.data().toString() + QChar::fromLatin1('%');
     option->textAlignment = Qt::AlignCenter;
     option->textVisible = true;
+    option->state |= QStyle::State_Horizontal;
 }
 
 QWidget *TodoCompleteDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(option);
-    Q_UNUSED(index);
+    Q_UNUSED(option)
+    Q_UNUSED(index)
 
-    TodoCompleteSlider *slider = new TodoCompleteSlider(parent);
+    auto slider = new TodoCompleteSlider(parent);
 
     slider->setRange(0, 100);
     slider->setOrientation(Qt::Horizontal);
@@ -118,21 +99,21 @@ QWidget *TodoCompleteDelegate::createEditor(QWidget *parent, const QStyleOptionV
 
 void TodoCompleteDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    QSlider *slider = static_cast<QSlider *>(editor);
+    auto slider = static_cast<QSlider *>(editor);
 
     slider->setValue(index.data(Qt::EditRole).toInt());
 }
 
 void TodoCompleteDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    QSlider *slider = static_cast<QSlider *>(editor);
+    auto slider = static_cast<QSlider *>(editor);
 
     model->setData(index, slider->value());
 }
 
 void TodoCompleteDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
 
     editor->setGeometry(option.rect);
 }
@@ -147,8 +128,7 @@ void TodoCompleteSlider::updateTip(int value)
 {
     QPoint p;
     p.setY(height() / 2);
-    p.setX(style()->sliderPositionFromValue(minimum(), maximum(),
-                                            value, width()));
+    p.setX(style()->sliderPositionFromValue(minimum(), maximum(), value, width()));
 
     const QString text = QStringLiteral("%1%").arg(value);
     QToolTip::showText(mapToGlobal(p), text, this);
@@ -164,10 +144,10 @@ TodoPriorityDelegate::TodoPriorityDelegate(QObject *parent)
 
 QWidget *TodoPriorityDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(option);
-    Q_UNUSED(index);
+    Q_UNUSED(option)
+    Q_UNUSED(index)
 
-    QComboBox *combo = new QComboBox(parent);
+    auto combo = new QComboBox(parent);
 
     combo->addItem(i18nc("@action:inmenu Unspecified priority", "unspecified"));
     combo->addItem(i18nc("@action:inmenu highest priority", "1 (highest)"));
@@ -185,21 +165,21 @@ QWidget *TodoPriorityDelegate::createEditor(QWidget *parent, const QStyleOptionV
 
 void TodoPriorityDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    QComboBox *combo = static_cast<QComboBox *>(editor);
+    auto combo = static_cast<QComboBox *>(editor);
 
     combo->setCurrentIndex(index.data(Qt::EditRole).toInt());
 }
 
 void TodoPriorityDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    QComboBox *combo = static_cast<QComboBox *>(editor);
+    auto combo = static_cast<QComboBox *>(editor);
 
     model->setData(index, combo->currentIndex());
 }
 
 void TodoPriorityDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
 
     editor->setGeometry(option.rect);
 }
@@ -214,33 +194,32 @@ TodoDueDateDelegate::TodoDueDateDelegate(QObject *parent)
 
 QWidget *TodoDueDateDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(option);
-    Q_UNUSED(index);
+    Q_UNUSED(option)
+    Q_UNUSED(index)
 
-    KDateComboBox *dateEdit = new KDateComboBox(parent);
+    auto dateEdit = new KDateComboBox(parent);
 
     return dateEdit;
 }
 
 void TodoDueDateDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    KDateComboBox *dateEdit = static_cast<KDateComboBox *>(editor);
+    auto dateEdit = static_cast<KDateComboBox *>(editor);
 
     dateEdit->setDate(index.data(Qt::EditRole).toDate());
 }
 
 void TodoDueDateDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    KDateComboBox *dateEdit = static_cast<KDateComboBox *>(editor);
+    auto dateEdit = static_cast<KDateComboBox *>(editor);
 
     model->setData(index, dateEdit->date());
 }
 
 void TodoDueDateDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(index);
-    editor->setGeometry(QStyle::alignedRect(QApplication::layoutDirection(), Qt::AlignCenter,
-                                            editor->size(), option.rect));
+    Q_UNUSED(index)
+    editor->setGeometry(QStyle::alignedRect(QApplication::layoutDirection(), Qt::AlignCenter, editor->size(), option.rect));
 }
 
 // ---------------- CATEGORIES DELEGATE --------------------------
@@ -254,27 +233,27 @@ TodoCategoriesDelegate::TodoCategoriesDelegate(QObject *parent)
 
 QWidget *TodoCategoriesDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(option);
-    Q_UNUSED(index);
+    Q_UNUSED(option)
+    Q_UNUSED(index)
 
     return new Akonadi::TagSelectionComboBox(parent);
 }
 
 void TodoCategoriesDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    auto *combo = static_cast<Akonadi::TagSelectionComboBox *>(editor);
+    auto combo = static_cast<Akonadi::TagSelectionComboBox *>(editor);
     combo->setSelection(index.data(Qt::EditRole).toStringList());
 }
 
 void TodoCategoriesDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    auto *combo = static_cast<Akonadi::TagSelectionComboBox *>(editor);
+    auto combo = static_cast<Akonadi::TagSelectionComboBox *>(editor);
     model->setData(index, combo->selectionNames());
 }
 
 void TodoCategoriesDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
 
     editor->setGeometry(option.rect);
 }
@@ -295,33 +274,29 @@ TodoRichTextDelegate::TodoRichTextDelegate(QObject *parent)
 
 void TodoRichTextDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    if (index.data(TodoModel::IsRichTextRole).toBool()) {
+    if (index.data(Akonadi::TodoModel::IsRichTextRole).toBool()) {
         QStyleOptionViewItem opt = option;
         initStyleOption(&opt, index);
 
         const QWidget *widget = opt.widget;
         QStyle *style = widget ? widget->style() : QApplication::style();
 
-        QRect textRect = style->subElementRect(QStyle::SE_ItemViewItemText,
-                                               &opt, widget);
+        QRect textRect = style->subElementRect(QStyle::SE_ItemViewItemText, &opt, widget);
 
         // draw the item without text
         opt.text.clear();
         style->drawControl(QStyle::CE_ItemViewItem, &opt, painter, widget);
 
         // draw the text (rich text)
-        QPalette::ColorGroup cg = (opt.state & QStyle::State_Enabled)
-                                  ? QPalette::Normal : QPalette::Disabled;
+        QPalette::ColorGroup cg = (opt.state & QStyle::State_Enabled) ? QPalette::Normal : QPalette::Disabled;
         if (cg == QPalette::Normal && !(opt.state & QStyle::State_Active)) {
             cg = QPalette::Inactive;
         }
 
         if (opt.state & QStyle::State_Selected) {
-            painter->setPen(
-                QPen(opt.palette.brush(cg, QPalette::HighlightedText), 0));
+            painter->setPen(QPen(opt.palette.brush(cg, QPalette::HighlightedText), 0));
         } else {
-            painter->setPen(
-                QPen(opt.palette.brush(cg, QPalette::Text), 0));
+            painter->setPen(QPen(opt.palette.brush(cg, QPalette::Text), 0));
         }
         if (opt.state & QStyle::State_Editing) {
             painter->setPen(QPen(opt.palette.brush(cg, QPalette::Text), 0));
@@ -351,7 +326,7 @@ void TodoRichTextDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
 QSize TodoRichTextDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QSize ret = QStyledItemDelegate::sizeHint(option, index);
-    if (index.data(TodoModel::IsRichTextRole).toBool()) {
+    if (index.data(Akonadi::TodoModel::IsRichTextRole).toBool()) {
         m_textDoc->setHtml(index.data().toString());
         ret = ret.expandedTo(m_textDoc->size().toSize());
     }
@@ -362,7 +337,6 @@ QSize TodoRichTextDelegate::sizeHint(const QStyleOptionViewItem &option, const Q
     }
 
     // This row might not have a checkbox, so give it more height so it appears the same size as other rows.
-    const int checkboxHeight = QApplication::style()->sizeFromContents(QStyle::CT_CheckBox, &option,
-                                                                       QSize()).height();
-    return QSize(ret.width(), qMax(ret.height(), checkboxHeight));
+    const int checkboxHeight = QApplication::style()->sizeFromContents(QStyle::CT_CheckBox, &option, QSize()).height();
+    return {ret.width(), qMax(ret.height(), checkboxHeight)};
 }
